@@ -92,10 +92,24 @@ BOS_FETCH_MODE = b"x-bce-fetch-mode"
 
 BOS_SERVER_SIDE_ENCRYPTION = b"x-bce-server-side-encryption"
 
+BOS_SERVER_SIDE_ENCRYPTION_CUSTOMER_KEY = b"x-bce-server-side-encryption-customer-key"
+
+BOS_SERVER_SIDE_ENCRYPTION_CUSTOMER_KEY_MD5 = b"x-bce-server-side-encryption-customer-key-md5"
+
 BOS_RESTORE_TIER = b"x-bce-restore-tier"
 
 BOS_RESTORE_DAYS = b"x-bce-restore-days"
 
+BOS_SYMLINK_TARGET = b"x-bce-symlink-target"
+
+BOS_SYMLINK_BUCKET = b"x-bce-symlink-bucket"
+
+BOS_FORBID_OVERWRITE = b"x-bce-forbid-overwrite"
+
+BOS_TRAFFIC_LIMIT = b"x-bce-traffic-limit"
+
 # STS HTTP Headers
 
 STS_SECURITY_TOKEN = b"x-bce-security-token"
+
+BOS_TAGGING = b"x-bce-tagging"
